@@ -16,11 +16,8 @@ importEvents <- function(rcon,
 importEvents.redcapApiConnection <- function(rcon, 
                                              data, 
                                              override       = FALSE,
-                                             ..., 
-                                             error_handling = getOption("redcap_error_handling"), 
-                                             config         = list(), 
-                                             api_param      = list()){
-  
+                                             ...)
+{
   dots <- list(...)
   if ("event_data" %in% names(dots)) data <- dots$event_data
   
@@ -40,20 +37,7 @@ importEvents.redcapApiConnection <- function(rcon,
                             len = 1, 
                             any.missing = FALSE, 
                             add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling, 
-                                        choices = c("null", "error"), 
-                                        .var.name = "error_handling",
-                                        add = coll)
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::assert_list(x = api_param, 
-                         names = "named", 
-                         add = coll)
-  
+
   checkmate::reportAssertions(coll)
   
   checkmate::assert_subset(x = names(data), 
@@ -71,21 +55,13 @@ importEvents.redcapApiConnection <- function(rcon,
                format = "csv", 
                returnFormat = "csv", 
                data = writeDataForImport(data))
-  
-  body <- body[lengths(body) > 0]
-  
+
   ###################################################################
   # Call the API
-  
-  response <- makeApiCall(rcon, 
-                          body = c(body, api_param), 
-                          config = config)
-  
   rcon$flush_events()
   rcon$flush_arms()
   rcon$flush_projectInformation()
-  
-  if (response$status_code != 200) return(redcapError(response, error_handling))
-  
-  invisible(as.character(response))
+  invisible(as.character(
+    makeApiCall(rcon, body, ...)
+  ))
 }
