@@ -14,10 +14,8 @@ importRepeatingInstrumentsEvents <- function(rcon,
 
 importRepeatingInstrumentsEvents.redcapApiConnection <- function(rcon, 
                                                                  data,
-                                                                 ..., 
-                                                                 error_handling = getOption("redcap_error_handling"), 
-                                                                 config         = list(), 
-                                                                 api_param      = list()){
+                                                                 ...)
+{
   ###################################################################
   # Argument Validation                                          ####
   
@@ -30,20 +28,7 @@ importRepeatingInstrumentsEvents.redcapApiConnection <- function(rcon,
   checkmate::assert_data_frame(x = data, 
                                col.names = "named",
                                add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling,
-                                        choices = c("null", "error"),
-                                        .var.name = "error_handling",
-                                        add = coll)
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::assert_list(x = api_param, 
-                         names = "named", 
-                         add = coll)
-  
+
   checkmate::reportAssertions(coll)
   
   checkmate::assert_subset(x = names(data), 
@@ -59,20 +44,12 @@ importRepeatingInstrumentsEvents.redcapApiConnection <- function(rcon,
                format = "csv", 
                returnFormat = "csv", 
                data = writeDataForImport(data))
-  
-  body <- body[lengths(body) > 0]
-  
+
   ###################################################################
   # Call the API                                                 ####
-  
-  response <- makeApiCall(rcon, 
-                          body = c(body, api_param), 
-                          config = config)
-  
   rcon$flush_projectInformation()
   rcon$flush_repeatInstrumentEvent()
-  
-  if (response$status_code != 200) return(redcapError(response, error_handling))
-  
-  invisible(as.character(response))
+  invisible(as.character(
+    makeApiCall(rcon, body, ...)
+  ))
 }
