@@ -14,10 +14,8 @@ importUserDagAssignments <- function(rcon,
 
 importUserDagAssignments.redcapApiConnection <- function(rcon,
                                                          data, 
-                                                         ..., 
-                                                         error_handling = getOption("redcap_error_handling"), 
-                                                         config = list(), 
-                                                         api_param = list()){
+                                                         ...)
+{
   ###################################################################
   # Argument Validation                                          ####
   
@@ -30,24 +28,9 @@ importUserDagAssignments.redcapApiConnection <- function(rcon,
   checkmate::assert_data_frame(x = data, 
                                col.names = "named", 
                                add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling, 
-                                        choices = c("null", "error"),
-                                        .var.name = "error_handling",
-                                        add = coll)
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::assert_list(x = api_param, 
-                         names = "named", 
-                         add = coll)
-  
+
   checkmate::reportAssertions(coll)
   
-  
-  
   checkmate::assert_subset(x = names(data), 
                            choices = c("username", 
                                        "redcap_data_access_group"), 
@@ -89,20 +72,10 @@ importUserDagAssignments.redcapApiConnection <- function(rcon,
                format = "csv", 
                returnFormat = "csv",
                data = writeDataForImport(data))
-  
-  body <- body[lengths(body) > 0]
-  
+
   ###################################################################
   # Make the API Call                                            ####
-  
-  response <- makeApiCall(rcon, 
-                          body = c(body, api_param), 
-                          config = config)
-  
-  if (response$status_code != 200){
-    redcapError(response, 
-                 error_handling = error_handling)
-  }
-  
-  invisible(as.character(response))
+  invisible(as.character(
+    makeApiCall(rcon, body, ...)
+  ))
 }
