@@ -28,7 +28,12 @@ format.invalid <- function(x, ...)
   if(is.null(vr)) vr <- "offline"
   if(is.null(pt)) pt <- "offline"
   
+  x$link_to_redcap <- ifelse(is.na(x$link_to_form), 
+                           "(link unavailable)", 
+                           sprintf("[link](%s)", x$link_to_form))
+
   x <- split(x, x$field_name)
+  
   paste0(
     "# Failed Validations from REDCap project '",  pt, "'\n\n",
     paste0(dt, "  \n"),
@@ -36,9 +41,9 @@ format.invalid <- function(x, ...)
     paste0("REDCap version ", vr, "  \n\n"),
     paste0(unlist(sapply(seq_along(x), function(i) {
       data <- x[[i]]
-      c(paste0("* Field[",data$field_type[1], "] '", names(x)[i], "' has ", nrow(data), " failure", ifelse(nrow(data) > 1, "s", "")),
+      c(paste0("* Field[",data$field_type[1], "] '", names(x)[i], "' on form '", data$form_name[1], "' has ", nrow(data), " failure", ifelse(nrow(data) > 1, "s", "")),
         if("record_id" %in% names(data) && !is.na(data$record_id[1])) 
-           paste0("  * Row ", data$row, ", Record Id '", data$record_id, "', Value '", data$value, "'") else
+           paste0("  * Row ", data$row, ", Record Id '", data$record_id, "', Value '", data$value, "' ", data$link_to_redcap) else
            paste0("  * Row ", data$row, ", Value '", data$value, "'")
       )
     })), collapse="\n"),
