@@ -37,24 +37,13 @@ test_that(
     skip_if(!RUN_USER_TESTS,
             "User tests without an expendable user could have negative consequences and are not run.")
     
-    rcon$refresh_users()
     if (EXPENDABLE_USER %in% rcon$users()$username){
       deleteUsers(rcon, 
                   users = EXPENDABLE_USER)
     }
     
-    rcon$refresh_users()
-    
-    # refresh argument works as intended 
     importUsers(rcon, 
-                data = data.frame(username = EXPENDABLE_USER), 
-                refresh = FALSE)
-    
-    expect_false(EXPENDABLE_USER %in% rcon$users()$username)
-    
-    importUsers(rcon, 
-                data = data.frame(username = EXPENDABLE_USER), 
-                refresh = TRUE)
+                data = data.frame(username = EXPENDABLE_USER))
     
     expect_true(EXPENDABLE_USER %in% rcon$users()$username)
     
