@@ -13,13 +13,10 @@ test_that(
 )
 
 test_that(
-  "Validate error_handling, config, api_param", 
+  "Validate config, api_param", 
   {
     local_reproducible_output(width = 200)
-    expect_error(exportUserRoleAssignments(rcon, 
-                                 error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
+   
     expect_error(exportUserRoleAssignments(rcon, 
                                  config = list(1)), 
                  "'config': Must have names")
@@ -103,15 +100,10 @@ test_that(
 )
 
 test_that(
-  "Validate error_handling, config, api_param", 
+  "Validate config, api_param", 
   {
     local_reproducible_output(width = 200)
-    expect_error(importUserRoleAssignments(rcon, 
-                                           data = REDCAP_USER_ROLE_ASSIGNMENT_STRUCTURE,
-                                           user_roles = "user-role",
-                                           error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
+
     expect_error(importUserRoleAssignments(rcon, 
                                            data = REDCAP_USER_ROLE_ASSIGNMENT_STRUCTURE,
                                            user_roles = "user-role",
