@@ -42,29 +42,6 @@ test_that(
   }
 )
 
-test_that(
-  "Validate error_handling, config, api_param", 
-  {
-    local_reproducible_output(width = 200)
-    expect_error(exportArms(rcon, 
-                            error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
-    expect_error(exportArms(rcon, 
-                            config = list(1)), 
-                 "'config': Must have names")
-    expect_error(exportArms(rcon, 
-                            config = "not a list"), 
-                 "'config': Must be of type 'list'")
-    
-    expect_error(exportArms(rcon, 
-                            api_param = list(1)), 
-                 "'api_param': Must have names")
-    expect_error(exportArms(rcon, 
-                            api_param = "not a list"), 
-                 "'api_param': Must be of type 'list'")
-  }
-)
 
 #####################################################################
 # Import Events Validation
@@ -122,11 +99,7 @@ test_that(
   "Return an error when error handling isn't one of null, error", 
   {
     local_reproducible_output(width = 200)
-    expect_error(importEvents(rcon, 
-                            data = Events,
-                            error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
+   
     expect_error(importEvents(rcon,
                             data = Events,
                             config = list(1)),
@@ -173,15 +146,10 @@ test_that(
 
 
 test_that(
-  "Validate error_handling, config, api_param", 
+  "Validate config, api_param", 
   {
     local_reproducible_output(width = 200)
     
-    expect_error(deleteEvents(rcon,
-                            events = "event_1_arm_1",
-                            error_handling = "not an option"), 
-                 "'error[_]handling': Must be element of set [{]'null','error'[}]")
-    
     expect_error(deleteEvents(rcon,
                             events = "event_1_arm_1",
                             config = list(1)), 
